@@ -25,8 +25,8 @@ impl YAxis {
         let chart_data = self.chart_data.borrow();
         let height = chart_data.height;
 
-        let min_value = chart_data.visible_candle_set.min_value;
-        let max_value = chart_data.visible_candle_set.max_value;
+        let min_value = chart_data.visible_candle_set.min_price;
+        let max_value = chart_data.visible_candle_set.max_price;
 
         (price - min_value) / (max_value - min_value) * height as f64
     }
@@ -40,8 +40,8 @@ impl YAxis {
 
     fn render_tick(&self, y: u16) -> String {
         let chart_data = self.chart_data.borrow();
-        let min_value = chart_data.visible_candle_set.min_value;
-        let max_value = chart_data.visible_candle_set.max_value;
+        let min_value = chart_data.visible_candle_set.min_price;
+        let max_value = chart_data.visible_candle_set.max_price;
         let height = chart_data.height;
 
         let price = min_value + (y as f64 * (max_value - min_value) / height as f64);
@@ -55,7 +55,7 @@ impl YAxis {
         )
     }
 
-    fn render_empty(&self) -> String {
+    pub fn render_empty(&self) -> String {
         let cell = " ".repeat((YAxis::CHAR_PRECISION + YAxis::DEC_PRECISION + 2) as usize);
         let margin = " ".repeat((YAxis::MARGIN_RIGHT + 1).try_into().unwrap());
 
